@@ -33,6 +33,7 @@
 
 #include <libpanel-util/panel-error.h>
 #include <libpanel-util/panel-glib.h>
+#include <libpanel-util/panel-show.h>
 
 #include "nothing.h"
 #include "panel-profile.h"
@@ -124,10 +125,10 @@ typedef struct {
 } OrientationComboItem;
 
 static OrientationComboItem orientation_items [] = {
-	{ N_("Orientation|Top"),    PANEL_ORIENTATION_TOP    },
-	{ N_("Orientation|Bottom"), PANEL_ORIENTATION_BOTTOM },
-	{ N_("Orientation|Left"),   PANEL_ORIENTATION_LEFT   },
-	{ N_("Orientation|Right"),  PANEL_ORIENTATION_RIGHT  }
+	{ NC_("Orientation", "Top"),    PANEL_ORIENTATION_TOP    },
+	{ NC_("Orientation", "Bottom"), PANEL_ORIENTATION_BOTTOM },
+	{ NC_("Orientation", "Left"),   PANEL_ORIENTATION_LEFT   },
+	{ NC_("Orientation", "Right"),  PANEL_ORIENTATION_RIGHT  }
 };
 
 static void
@@ -179,7 +180,7 @@ panel_properties_dialog_setup_orientation_combo (PanelPropertiesDialog *dialog,
 	for (i = 0; i < G_N_ELEMENTS (orientation_items); i++) {
 		gtk_list_store_append (model, &iter);
 		gtk_list_store_set (model, &iter,
-				    COLUMN_TEXT, Q_(orientation_items [i].name),
+				    COLUMN_TEXT, g_dpgettext2 (NULL, "Orientation", orientation_items [i].name),
 				    COLUMN_ITEM, &(orientation_items [i]),
 				    -1);
 		if (orientation == orientation_items [i].orientation)
@@ -449,10 +450,7 @@ panel_properties_dialog_setup_image_chooser (PanelPropertiesDialog *dialog,
 	dialog->image_chooser = glade_xml_get_widget (gui, "image_chooser");
 
 	filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (filter, _("Images"));
 	gtk_file_filter_add_pixbuf_formats (filter);
-	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog->image_chooser),
-				     filter);
 	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog->image_chooser),
 				     filter);
 
@@ -648,7 +646,7 @@ panel_properties_dialog_response (PanelPropertiesDialog *dialog,
 			help_id = "gospanel-28";
 		}
 		panel_show_help (gtk_window_get_screen (GTK_WINDOW (properties_dialog)),
-				 "user-guide.xml", help_id);
+				 "user-guide", help_id, NULL);
 		break;
 	default:
 		break;
