@@ -12,6 +12,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <bonobo/bonobo-exception.h>
+#include <bonobo/bonobo-main.h>
 #include <bonobo/bonobo-widget.h>
 #include <gconf/gconf.h>
 
@@ -50,21 +51,21 @@ typedef struct {
 } ComboItem;
 
 static ComboItem orient_items [] = {
-	{ N_("Orientation|Top"),    "top"    },
-	{ N_("Orientation|Bottom"), "bottom" },
-	{ N_("Orientation|Left"),   "left"   },
-	{ N_("Orientation|Right"),  "right"  }
+	{ NC_("Orientation", "Top"),    "top"    },
+	{ NC_("Orientation", "Bottom"), "bottom" },
+	{ NC_("Orientation", "Left"),   "left"   },
+	{ NC_("Orientation", "Right"),  "right"  }
 };
 
 
 static ComboItem size_items [] = {
-	{ N_("Size|XX Small"), "xx-small" },
-	{ N_("Size|X Small"),  "x-small"  },
-	{ N_("Size|Small"),    "small"    },
-	{ N_("Size|Medium"),   "medium"   },
-	{ N_("Size|Large"),    "large"    },
-	{ N_("Size|X Large"),  "x-large"  },
-	{ N_("Size|XX Large"), "xx-large" }
+	{ NC_("Size", "XX Small"), "xx-small" },
+	{ NC_("Size", "X Small"),  "x-small"  },
+	{ NC_("Size", "Small"),    "small"    },
+	{ NC_("Size", "Medium"),   "medium"   },
+	{ NC_("Size", "Large"),    "large"    },
+	{ NC_("Size", "X Large"),  "x-large"  },
+	{ NC_("Size", "XX Large"), "xx-large" }
 };
 
 static char *
@@ -192,10 +193,11 @@ on_execute_button_clicked (GtkButton *button,
 }
 
 static void
-setup_combo (GtkWidget *combo_box,
-	     ComboItem *items,
-	     int        nb_items,
-	     gboolean   dynamic)
+setup_combo (GtkWidget  *combo_box,
+	     ComboItem  *items,
+	     const char *context,
+	     int         nb_items,
+	     gboolean    dynamic)
 {
 	GtkListStore          *model;
 	GtkTreeIter            iter;
@@ -213,7 +215,7 @@ setup_combo (GtkWidget *combo_box,
 	for (i = 0; i < nb_items; i++) {
 		gtk_list_store_append (model, &iter);
 		gtk_list_store_set (model, &iter,
-				    COLUMN_TEXT, dynamic ? g_strdup (items [i].name) : Q_(items [i].name),
+				    COLUMN_TEXT, dynamic ? g_strdup (items [i].name) : g_dpgettext2 (NULL, context, items [i].name),
 				    COLUMN_ITEM, dynamic ? g_strdup (items [i].value) : items [i].value,
 				    -1);
 	}
@@ -261,12 +263,13 @@ setup_options (void)
 		applet_items[i].value = info->iid;
 	}
 
-	setup_combo (applet_combo, applet_items, applet_nb, TRUE);
+	setup_combo (applet_combo, applet_items, NULL, applet_nb, TRUE);
 	g_free (applet_items);
 	CORBA_free (applets);
 
-	setup_combo (size_combo, size_items, G_N_ELEMENTS (size_items), FALSE);
-	setup_combo (orient_combo, orient_items,
+	setup_combo (size_combo, size_items, "Size",
+		     G_N_ELEMENTS (size_items), FALSE);
+	setup_combo (orient_combo, orient_items, "Orientation",
 		     G_N_ELEMENTS (orient_items), FALSE);
 
 	unique_key = gconf_unique_key ();
@@ -279,24 +282,31 @@ setup_options (void)
 int
 main (int argc, char **argv)
 {
-	GOptionContext *context;
-	GladeXML       *gui;
-	char           *gladefile;
+	GladeXML *gui;
+	char     *gladefile;
+	GError   *error;
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	context = g_option_context_new ("");
+	error = NULL;
+	if (!gtk_init_with_args (&argc, &argv,
+				 "", (GOptionEntry *) options, GETTEXT_PACKAGE,
+				 &error)) {
+		if (error) {
+			g_printerr ("%s\n", error->message);
+			g_error_free (error);
+		} else
+			g_printerr ("Cannot initiliaze GTK+.\n");
 
-	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+		return 1;
+	}
 
-	gnome_program_init (argv [0], "0.0.0.0", LIBGNOMEUI_MODULE,
-			    argc, argv,
-			    GNOME_PARAM_GOPTION_CONTEXT, context,
-			    GNOME_PARAM_NONE);
-
-	g_option_context_free (context);
+	if (!bonobo_init (&argc, argv)) {
+		g_printerr ("Cannot initialize bonobo.\n");
+		return 1;
+	}
 
 	if (cli_iid) {
 		load_applet_from_command_line ();
